from default import *  # noqa

NOSE_ARGS = [
    '--with-coverage',
    '--cover-package=rapidsms',
]
